@@ -39,7 +39,7 @@ module Hanayu
       @dbpath = File.join(@dir, DBNAME)
       @graphs = {}
       @data = read_hanayu_txt(@dir)
-      if @data != nil and not @data.empty?
+      unless @data.nil? or @data.empty?
         read_db()
         return 1
       else
@@ -56,12 +56,8 @@ module Hanayu
           tmp_name = ''
           for line in f
             line = line.encode('UTF-8', :invalid => :replace, :undef => :replace).strip()
-            if line.empty?
-              next
-            end
-            if line.start_with?('//')
-              next
-            end
+            next if line.empty?
+            next if line.start_with?('//')
             if line.start_with?('[') # bln.txt like format
               graphs[name] = data
               data = {}
@@ -87,9 +83,7 @@ module Hanayu
               tmp_name = line
             end
           end
-          if not data.empty?
-            graphs[name] = data
-          end
+          graphs[name] = data unless data.empty?
           return graphs
         end
       rescue
@@ -98,9 +92,7 @@ module Hanayu
     end
 
     def finalize
-      for name in @graphs.keys()
-        @graphs[name].destroy()
-      end
+      @graphs.each_key {|name| @graphs[name].destroy() }
       @graphs = {}
       @data = {}
       write_db()
@@ -111,7 +103,7 @@ module Hanayu
       year = base.year
       month = base.month
       day = base.day
-      target_time = Time.new(year, month, day, 0, 0, 0) + offset * 24 *60 * 60
+      target_time = (Time.new(year, month, day, 0, 0, 0) + offset * 24 *60 * 60)
       year = target_time.year
       month = target_time.month
       day = target_time.day
@@ -131,18 +123,14 @@ module Hanayu
           ver = nil
           for line in f
             line = line.strip()
-            if line.empty?
-              next
-            end
-            if ver == nil
+            next if line.empty?
+            if ver.nil?
               if line == '# Format: v1.0'
                 ver = 1
               end
               next
             end
-            if not line.include?(',')
-              next
-            end
+            next unless line.include?(',')
             key, value = line.split(',', 2)
             for index_ in 0..6
               if @seven_days[index_][0] == key
@@ -171,10 +159,10 @@ module Hanayu
           if @seven_days[j][0] == key
             @seven_days[j][4] = old_seven_days[i][4]
             if j == 6
-              @seven_days[j][4] = @seven_days[j][4] + \
-                                  (current_time - \
-                                   @last_update) / \
-                                  (60.0 * 60.0)
+              @seven_days[j][4] = (@seven_days[j][4] + \
+                                   (current_time - \
+                                    @last_update) / \
+                                   (60.0 * 60.0))
             end
           end
         end
@@ -197,11 +185,10 @@ module Hanayu
     end
 
     def execute(argument)
-      if argument == nil or argument.empty?
-        return RESPONSE[400]
-      end
+      return RESPONSE[400] if argument.nil? or argument.empty?
       command = argument[0]
-      if command == 'show'
+      case command
+      when 'show'
         if argument.length >= 2
           name = argument[1]
           if @graphs.include?(name)
@@ -210,16 +197,15 @@ module Hanayu
         else
           name = ''
         end
-        if not @data.include?(name)
-          return RESPONSE[400]
-        end
+        return RESPONSE[400] unless @data.include?(name)
         if @data[name].include?('graph') and \
            ['line', 'bar', 'radar', 'radar2'].include?(@data[name]['graph'])
           graph_type = @data[name]['graph']
         else
           graph_type = 'usetime'
         end
-        if graph_type == 'usetime'
+        case graph_type
+        when 'usetime'
           update_db()
           new_args = []
           for index_ in 0..6
@@ -232,20 +218,20 @@ module Hanayu
           end
           @graphs[name] = Line.new(
             @dir, @data[name], :args => new_args, :limit_min => 0, :limit_max => 24)
-        elsif graph_type == 'line'
+        when 'line'
           @graphs[name] = Line.new(
             @dir, @data[name], :args => argument[2..-1])
-        elsif graph_type == 'bar'
+        when 'bar'
           @graphs[name] = Bar.new(
             @dir, @data[name], :args => argument[2..-1])
-        elsif graph_type == 'radar'
+        when 'radar'
           @graphs[name] = Radar.new(
             @dir, @data[name], :args => argument[2..-1])
-        elsif graph_type == 'radar2'
+        when 'radar2'
           @graphs[name] = Radar2.new(
             @dir, @data[name], :args => argument[2..-1])
         end
-      elsif command == 'hide'
+      when 'hide'
         if argument.length >= 2
           name = argument[1]
         else
@@ -291,8 +277,8 @@ module Hanayu
       left, top = 0, 0 # XXX
       scrn_w = scrn.width - left
       scrn_h = scrn.height - top
-      @x = left + (scrn_w / 2).to_i
-      @y = top + (scrn_h / 4).to_i
+      @x = (left + (scrn_w / 2).to_i)
+      @y = (top + (scrn_h / 4).to_i)
       @window.move(@x, @y)
       @darea = Gtk::DrawingArea.new
       @darea.set_events(Gdk::EventMask::EXPOSURE_MASK|
@@ -323,7 +309,7 @@ module Hanayu
     end
 
     def get_color(target)
-      raise "assert" unless ['font', 'line', 'frame', 'bar', 'background'].include?(target)
+      fail "assert" unless ['font', 'line', 'frame', 'bar', 'background'].include?(target)
       if target == 'background'
         r = g = b = 255 # white
       else
@@ -352,9 +338,8 @@ module Hanayu
     end
 
     def draw_title(widget, cr)
-      if @data.include?('title')
-        @title = @data['title']
-      end
+      return unless @data.has_key?('title')
+      @title = @data['title']
       font_size = 12 # pixel
       @font_desc = Pango::FontDescription.new
       @font_desc.set_family('Sans')
@@ -389,7 +374,7 @@ module Hanayu
       cr.save()
       cr.set_source_rgb(*get_color('background'))
       cr.paint()
-      if @surface != nil
+      unless @surface.nil?
         width = @surface.width
         height = @surface.height
         xoffset = ((WIDTH - width) / 2).to_i
@@ -411,11 +396,12 @@ module Hanayu
     end
 
     def button_press(window, event)
-      if event.event_type == Gdk::EventType::BUTTON_PRESS
+      case event.event_type
+      when Gdk::EventType::BUTTON_PRESS
         @window.begin_move_drag(
           event.button, event.x_root.to_i, event.y_root.to_i,
           event.time)
-      elsif event.event_type == Gdk::EventType::DOUBLE_BUTTON_PRESS # double click
+      when Gdk::EventType::DOUBLE_BUTTON_PRESS # double click
         destroy()
       end
       return true
@@ -426,11 +412,9 @@ module Hanayu
     end
 
     def destroy
-      if @window != nil
-        @window.destroy()
-        @window = nil
-        @timeout_id = nil
-      end
+      @window.destroy() unless @window.nil?
+      @window = nil
+      @timeout_id = nil
     end
   end
 
@@ -457,12 +441,12 @@ module Hanayu
       for index_ in 0..num-1
         @layout.set_text(@args[index_ * 2])
         w, h = @layout.pixel_size
-        pos_x = 60 + index_ * step + (step / 2).to_i - (w / 2).to_i
+        pos_x = (60 + index_ * step + (step / 2).to_i - (w / 2).to_i)
         pos_y = 268
         cr.move_to(pos_x, pos_y)
         cr.show_pango_layout(@layout)
       end
-      if @min != nil
+      unless @min.nil?
         limit_min = @min
       else
         limit_min = @args[1]
@@ -472,7 +456,7 @@ module Hanayu
           end
         end
       end
-      if @max != nil
+      unless @max.nil?
         limit_max = @max
       else
         limit_max = @args[1]
@@ -489,11 +473,11 @@ module Hanayu
       cr.set_line_width(line_width)
       cr.set_source_rgb(*get_color('line'))
       for index_ in 1..num-1
-        src_x = 60 + (index_ - 1) * step + (step / 2).to_i
-        src_y = 220 - (
-          168 * @args[(index_ - 1) * 2 + 1] / (limit_max - limit_min)).to_i
-        dst_x = 60 + index_ * step + (step / 2).to_i
-        dst_y = 220 - (168 * @args[index_ * 2 + 1] / (limit_max - limit_min)).to_i
+        src_x = (60 + (index_ - 1) * step + (step / 2).to_i)
+        src_y = (220 - (
+          168 * @args[(index_ - 1) * 2 + 1] / (limit_max - limit_min)).to_i)
+        dst_x = (60 + index_ * step + (step / 2).to_i)
+        dst_y = (220 - (168 * @args[index_ * 2 + 1] / (limit_max - limit_min)).to_i)
         cr.move_to(src_x, src_y)
         cr.line_to(dst_x, dst_y)
         cr.stroke()
@@ -533,12 +517,12 @@ module Hanayu
             end
           end
         end
-        if surface != nil
+        unless surface.nil?
           w = surface.width
           h = surface.height
-          x = 60 + index_ * step + (step / 2).to_i - (w / 2).to_i
-          y = 220 - (
-            168 * @args[index_ * 2 + 1] / (limit_max - limit_min)).to_i - (h / 2).to_i
+          x = (60 + index_ * step + (step / 2).to_i - (w / 2).to_i)
+          y = (220 - (
+            168 * @args[index_ * 2 + 1] / (limit_max - limit_min)).to_i - (h / 2).to_i)
           cr.set_source(surface, x, y)
           cr.paint()
         end
@@ -591,8 +575,8 @@ module Hanayu
       cr.set_source_rgb(*get_color('frame'))
       num = (@args.length / 2).to_i
       for index_ in 0..num-1
-        x = 146 + (Math.cos(Math::PI * (0.5 - 2.0 * index_ / num)) * 114).to_i
-        y = 146 - (Math.sin(Math::PI * (0.5 - 2.0 * index_ / num)) * 114).to_i
+        x = (146 + (Math.cos(Math::PI * (0.5 - 2.0 * index_ / num)) * 114).to_i)
+        y = (146 - (Math.sin(Math::PI * (0.5 - 2.0 * index_ / num)) * 114).to_i)
         cr.move_to(146, 146,)
         cr.line_to(x, y)
         cr.stroke()
@@ -631,25 +615,25 @@ module Hanayu
       cr.set_line_width(line_width)
       cr.set_source_rgb(*get_color('line'))
       if limit_max > 0
-        value = @args[(num - 1) * 2 + 1] / limit_max
+        value = (@args[(num - 1) * 2 + 1] / limit_max)
       else
         value = 1.0
       end
-      src_x = 146 + (Math.cos(
-                      Math::PI * (0.5 - 2.0 * (num - 1) / num)) * value * 100).to_i
-      src_y = 146 - (Math.sin(
-                      Math::PI * (0.5 - 2.0 * (num - 1) / num)) * value * 100).to_i
+      src_x = (146 + (Math.cos(
+                       Math::PI * (0.5 - 2.0 * (num - 1) / num)) * value * 100).to_i)
+      src_y = (146 - (Math.sin(
+                       Math::PI * (0.5 - 2.0 * (num - 1) / num)) * value * 100).to_i)
       cr.move_to(src_x, src_y)
       for index_ in 0..num-1
         if limit_max > 0
-          value = @args[index_ * 2 + 1] / limit_max
+          value = (@args[index_ * 2 + 1] / limit_max)
         else
           value = 1.0
         end
-        dst_x = 146 + (
-          Math.cos(Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i
-        dst_y = 146 - (
-          Math.sin(Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i
+        dst_x = (146 + (
+          Math.cos(Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i)
+        dst_y = (146 - (
+          Math.sin(Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i)
         cr.line_to(dst_x, dst_y)
       end
       cr.stroke()
@@ -659,15 +643,15 @@ module Hanayu
       cr.set_source_rgb(*get_color('font'))
       for index_ in 0..num-1
         ##if limit_max > 0
-        ##  value = @args[index_ * 2 + 1] / limit_max
+        ##  value = (@args[index_ * 2 + 1] / limit_max)
         ##else
         ##  value = 1.0
         ##end
         value = 1.2 # XXX
-        x = 146 + (Math.cos(
-                    Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i
-        y = 146 - (Math.sin(
-                    Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i
+        x = (146 + (Math.cos(
+                    Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i)
+        y = (146 - (Math.sin(
+                    Math::PI * (0.5 - 2.0 * index_ / num)) * value * 100).to_i)
         @layout.set_text(@args[index_ * 2])
         w, h = @layout.pixel_size
         x -= (w / 2).to_i
