@@ -30,9 +30,7 @@ module Httpc
     end
 
     def finalize
-      for timeout_id in @__bg.keys
-        GLib::Source.remove(timeout_id)
-      end
+      @__bg.each_key {|timeout_id| GLib::Source.remove(timeout_id) }
       return 1
     end
 
@@ -41,41 +39,33 @@ module Httpc
     end
 
     def check_import
-      if @__sakura != nil
-        return 1
-      else
-        return 0
-      end
+      @__sakura.nil? ? 0 : 1
     end
 
     def get(url, start: nil, end_: nil)
       url = URI.parse(url)
-      if not ((url.scheme == 'http' or url.scheme == 'https') and
-              #url.params == nil and
-              url.query == nil and
-              url.fragment == nil)
+      unless ((url.scheme == 'http' or url.scheme == 'https') and
+              #url.params.nil? and
+              url.query.nil? and
+              url.fragment.nil?)
         return RESPONSE[400] # XXX
       end
       data = open(url) do |f|
         @charset = f.charset
         f.read()
       end
-      if start != nil
-        fail "assert" unless end_ != nil
+      unless start.nil?
+        fail "assert" if end_.nil?
         nc = 0
         ls = start.length
         le = end_.length
         result = []
         while true
           ns = data.index(start, nc)
-          if ns == nil
-            break
-          end
+          break if ns.nil?
           ns += ls
           ne = data.index(end_, ns)
-          if ne == nil
-            break
-          end
+          break if ne.nil?
           nc = (ne + le)
           result << data[ns..ne-1]
         end
@@ -86,9 +76,7 @@ module Httpc
     end
 
     def execute(argument)
-      if argument == nil
-        return RESPONSE[400]
-      end
+      return RESPONSE[400] if argument.nil?
       bg = nil
       @charset = nil
       process_tag = nil
@@ -103,48 +91,45 @@ module Httpc
         end
       end
       if argument.length >= 1
-        if ['sjis', 'utf-8', 'utf-16be', 'utf-16le'].include?(argument[0])
+        case argument[0]
+        when 'sjis', 'utf-8', 'utf-16be', 'utf-16le'
           @charset = argument[0]
           argument = argument[1..-1]
-        elsif argument[0] == 'euc'
+        when 'euc'
           @charset = 'EUC-JP'
           argument = argument[1..-1]
-        elsif argument[0] == 'jis'
+        when 'jis'
           @charset = 'ISO-2022-JP '
           argument = argument[1..-1]
         end
-        if argument[0] == 'erase_tag'
+        case argument[0]
+        when 'erase_tag'
           process_tag = lambda {} ## FIXME: not supported yet
           argument = argument[1..-1]
-        elsif argument[0] == 'translate_tag'
+        when 'translate_tag'
           process_tag = lambda {} ## FIXME: not supported yet
           argument = argument[1..-1]
         end
       end
       if argument.empty?
-        ##fail "assert" unless bg == nil and process_tag == nil
-        return "SAORI/1.0 200 OK\r\nResult: " + @loaded.to_s + " \r\n\r\n"
+        ##fail "assert" unless bg.nil? and process_tag.nil?
+        return "SAORI/1.0 200 OK\r\nResult: #{@loaded} \r\n\r\n"
       elsif argument.length > 3
         return RESPONSE[400]
       elsif argument.length == 2 # FIXME: not supported yet
         return "SAORI/1.0 200 OK\r\nResult: 0\r\n\r\n"
       else
-        if bg != nil # needs multi-threading?
+        if not bg.nil? # needs multi-threading?
           timeout_id = GLib::Timeout.add(1000) { notify(bg, argument, process_tag) } # XXX
           @__bg[timeout_id] = bg
           return nil # "SAORI/1.0 204 No Content\r\n\r\n"
         else
           data = get(argument[0], :start => argument[1], :end_ => argument[2])
-          if data.empty?
-            return nil # "SAORI/1.0 204 No Content\r\n\r\n"
-          end
-          if data == RESPONSE[400] # XXX
-            return data
-          end
-          result = "SAORI/1.0 200 OK\r\n" + "Result: " + data[0].to_s + "\r\n"
+          return nil if data.empty? # "SAORI/1.0 204 No Content\r\n\r\n"
+          return data if data == RESPONSE[400] # XXX
+          result = "SAORI/1.0 200 OK\r\nResult: #{data[0]}\r\n"
           for n in 0..data.length-1
-            result = [result,
-                      "Value" + n.to_s + ": " + data[n].to_s + "\r\n"].join("")
+            result = [result, "Value#{n}: #{data[n]}\r\n"].join("")
           end
           result += "\r\n"
           return result.encode('Shift_JIS', :invalid => :replace, :undef => :replace)
@@ -154,7 +139,7 @@ module Httpc
 
     def notify(id, argument, process_tag)
       result = get(argument[0], :start => argument[1], :end_ => argument[2])
-      if process_tag != nil
+      if not process_tag.nil?
         #pass ## FIXME: not supported yet
       end
       @__sakura.notify_event('OnHttpcNotify', id, nil, *result)
