@@ -77,7 +77,8 @@ module Nekodorif
         'settings' => [['Settings', nil, _('Settings...(_O)'), nil,
                         '', lambda {|a, b| @parent.handle_request('NOTIFY', 'edit_preferences')}],
                        '/ui/popup/Settings'],
-        'katochan' => [['Katochan', nil, _('Katochan(_K)'), nil],
+        'katochan' => [['Katochan', nil, _('Katochan(_K)'), nil,
+                       '', lambda {|a, b| }],
                        '/ui/popup/Katochan'],
         'exit' =>     [['Exit', nil,_('Exit(_Q)'), nil,
                         '', lambda {|a, b| @parent.handle_request('NOTIFY', 'close')}],
@@ -112,10 +113,10 @@ module Nekodorif
 
     def __set_katochan_menu(list)
       key = 'katochan'
-      if not list.empty?
+      unless list.empty?
         menu = Gtk::Menu.new()
         for katochan in list
-          item = Gtk::MenuItem.new(katochan['name'])
+          item = Gtk::MenuItem.new(:label => katochan['name'])
           item.signal_connect('activate', katochan) do |a, k|
             @parent.handle_request('NOTIFY', 'select_katochan', k)
             next true
@@ -143,31 +144,23 @@ module Nekodorif
 
     def observer_update(event, args)
       if ['set position', 'set surface'].include?(event)
-        if @skin != nil
-          @skin.set_position()
-        end
-        if @katochan != nil and @katochan.loaded
+        @skin.set_position() unless @skin.nil?
+        if not @katochan.nil? and @katochan.loaded
           @katochan.set_position()
         end
       elsif event == 'set scale'
         scale = @target.get_surface_scale()
-        if @skin != nil
-          @skin.set_scale(scale)
-        end
-        if @katochan != nil
-          @katochan.set_scale(scale)
-        end
+        @skin.set_scale(scale) unless @skin.nil?
+        @katochan.set_scale(scale) unless @katochan.nil?
       elsif event == 'finalize'
         finalize()
       else
-        Logging::Logging.debug('OBSERVER(nekodorif): ignore - ' + event)
+        Logging::Logging.debug("OBSERVER(nekodorif): ignore - #{event}")
       end
     end
 
     def load(dir, katochan, target)
-      if katochan.empty?
-        return 0
-      end
+      return 0 if katochan.empty?
       @dir = dir
       @target = target
       @target.attach_observer(self)
@@ -175,9 +168,7 @@ module Nekodorif
       scale = @target.get_surface_scale()
       @skin = Skin.new(@dir, @accelgroup, scale)
       @skin.set_responsible(self)
-      if @skin == nil
-        return 0
-      end
+      return 0 if @skin.nil?
       @katochan_list = katochan
       @katochan = nil
       launch_katochan(@katochan_list[0])
@@ -187,7 +178,7 @@ module Nekodorif
     end
 
     def handle_request(event_type, event, *arglist)
-      raise "assert" unless ['GET', 'NOTIFY'].include?(event_type)
+      fail "assert" unless ['GET', 'NOTIFY'].include?(event_type)
       handlers = {
         'get_katochan_list' =>  lambda { return @katochan_list },
         'get_mode' =>  lambda { return @mode },
@@ -201,19 +192,13 @@ module Nekodorif
           result = nil # XXX
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def do_idle_tasks
-      if not @__running
-        return false
-      end
+      return false unless @__running
       @skin.update()
-      if @katochan != nil
-        @katochan.update()
-      end
+      @katochan.update() unless @katochan.nil?
       #process_script()
       return true
     end
@@ -236,7 +221,7 @@ module Nekodorif
     end
 
     def has_katochan
-      if @katochan != nil
+      unless @katochan.nil?
         return true
       else
         return false
@@ -258,9 +243,7 @@ module Nekodorif
     end
 
     def launch_katochan(katochan)
-      if @katochan != nil
-        delete_katochan
-      end
+      delete_katochan unless @katochan.nil?
       @katochan = Katochan.new(@target)
       @katochan.set_responsible(self)
       @katochan.load(katochan)
@@ -272,12 +255,8 @@ module Nekodorif
     def finalize
       @__running = false
       @target.detach_observer(self)
-      if @katochan != nil
-        @katochan.destroy()
-      end
-      if @skin != nil
-        @skin.destroy()
-      end
+      @katochan.destroy() unless @katochan.nil?
+      @skin.destroy() unless @skin.nil?
       ##if self.balloon is not None:
       ##    self.balloon.destroy()
     end
@@ -300,7 +279,7 @@ module Nekodorif
       @__menu = Menu.new(@accelgroup)
       @__menu.set_responsible(self)
       path = File.join(@dir, 'omni.txt')
-      if File.file?(path) and File.size(path) == 0
+      if File.file?(path) and File.size(path).zero?
         @omni = 1
       else
         @omni = 0
@@ -351,10 +330,10 @@ module Nekodorif
     end
 
     def handle_request(event_type, event, *arglist)
-      raise "assert" unless ['GET', 'NOTIFY'].include?(event_type)
+      fail "assert" unless ['GET', 'NOTIFY'].include?(event_type)
       handlers = {
       }
-      if not handlers.include?(event)
+      unless handlers.include?(event)
         result = @parent.handle_request(event_type, event, *arglist)
       else
         if Skin.method_defined?(event)
@@ -363,9 +342,7 @@ module Nekodorif
           result = nil
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def set_scale(scale)
@@ -418,9 +395,9 @@ module Nekodorif
     end
 
     def set_surface
-      if @id[1] != nil
+      unless @id[1].nil?
         path = File.join(@dir, 'surface' + @id[0].to_s + @id[1].to_s + '.png')
-        if not File.exists?(path)
+        unless File.exists?(path)
           @id[1] = nil
           set_surface()
           return
@@ -444,32 +421,26 @@ module Nekodorif
 
     def set_position(reset: 0)
       left, top, scrn_w, scrn_h = @window.workarea
-      if reset != 0
+      unless reset.zero?
         @x = left
-        @y = top + scrn_h - @h
+        @y = (top + scrn_h - @h)
       else
-        if @omni != 0
-          @y = top + scrn_h - @h
-        end
+        @y = (top + scrn_h - @h) unless @omni.zero?
       end
       @window.move(@x, @y)
     end
 
     def move(x_delta, y_delta)
-      @x = @x + x_delta
-      if @omni != 0
-        @y = @y + y_delta
-      end
+      @x = (@x + x_delta)
+      @y = (@y + y_delta) unless @omni.zero?
       set_position()
     end
 
     def update
-      if @id[1] != nil
+      unless @id[1].nil?
         @id[1] += 1
       else
-        if Random.rand(0..99) != 0 ## XXX
-          return
-        end
+        return unless Random.rand(0..99).zero? ## XXX
         @id[1] = 0
       end
       set_surface()
@@ -498,8 +469,7 @@ module Nekodorif
     def motion_notify(widget, event)
       x, y, state = event.x, event.y, event.state
       if state & Gdk::ModifierType::BUTTON1_MASK
-        if @x_root != nil and \
-          @y_root != nil
+        unless @x_root.nil? or @y_root.nil?
           @dragged = true
           x_delta = (event.x_root - @x_root).to_i
           y_delta = (event.y_root - @y_root).to_i
@@ -566,11 +536,11 @@ module Nekodorif
     end
 
     def get_name
-      return @data['name']
+      @data['name']
     end
 
     def get_category
-      return @data['category']
+      @data['category']
     end
 
     def get_kinoko_flag ## FIXME
@@ -578,7 +548,7 @@ module Nekodorif
     end
 
     def get_target
-      if @side == 0
+      if @side.zero?
         return @target.get_selfname()
       else
         return @target.get_keroname()
@@ -607,7 +577,7 @@ module Nekodorif
     end
 
     def set_movement(timing)
-      key = timing + 'fall.type'
+      key = (timing + 'fall.type')
       if @data.include?(key) and \
         ['gravity', 'evenspeed', 'none'].include?(@data[key])
           @settings['fall.type'] = @data[key]
@@ -617,7 +587,7 @@ module Nekodorif
       if @data.include?(timing + 'fall.speed')
         @settings['fall.speed'] = @data[timing + 'fall.speed']
       else
-        @settings['fall.speed'] =1
+        @settings['fall.speed'] = 1
       end
       if @settings['fall.speed'] < 1
         @settings['fall.speed'] = 1
@@ -625,7 +595,7 @@ module Nekodorif
       if @settings['fall.speed'] > 100
         @settings['fall.speed'] = 100
       end
-      key = timing + 'slide.type'
+      key = (timing + 'slide.type')
       if @data.include?(key) and \
         ['none', 'sinwave', 'leaf'].include?(@data[key])
         @settings['slide.type'] = @data[key]
@@ -665,14 +635,12 @@ module Nekodorif
     end
 
     def set_position
-      if @settings['state'] != 'before'
-        return
-      end
+      return if @settings['state'] != 'before'
       target_x, target_y = @target.get_surface_position(@side)
       target_w, target_h = @target.get_surface_size(@side)
       left, top, scrn_w, scrn_h = @window.workarea
-      @x = target_x + target_w / 2 - @w / 2 + (@offset_x * @__scale / 100).to_i
-      @y = top + (@offset_y * @__scale / 100).to_i
+      @x = (target_x + target_w / 2 - @w / 2 + (@offset_x * @__scale / 100).to_i)
+      @y = (top + (@offset_y * @__scale / 100).to_i)
       @window.move(@x, @y)
     end
 
@@ -698,8 +666,8 @@ module Nekodorif
       set_state('before')
       if @data.include?('category')
         category = @data['category'].split(',', 0)
-        if not category.empty?
-          if not CATEGORY_LIST.include?(category[0])
+        unless category.empty?
+          unless CATEGORY_LIST.include?(category[0])
             Logging::Logging.warning('WARNING: unknown major category - ' + category[0])
             ##@data['category'] = CATEGORY_LIST[-1]
           end
@@ -799,8 +767,8 @@ module Nekodorif
         #pass
       else
         if @settings['fall.type'] == 'gravity'
-          @y += @settings['fall.speed'].to_i * \
-          (@time / 20.0)**2
+          @y += (@settings['fall.speed'].to_i * \
+          (@time / 20.0)**2)
         elsif @settings['fall.type'] == 'evenspeed'
           @y += @settings['fall.speed']
         else
@@ -819,10 +787,10 @@ module Nekodorif
       for side in [0, 1]
         target_x, target_y = @target.get_surface_position(side)
         target_w, target_h = @target.get_surface_size(side)
-        center_x = @x + @w / 2
-        center_y = @y + @h / 2
-        if target_x < center_x and center_x < target_x + target_w and \
-          target_y < center_y and center_y < target_y + target_h
+        center_x = (@x + @w / 2)
+        center_y = (@y + @h / 2)
+        if target_x < center_x and center_x < (target_x + target_w) and \
+          target_y < center_y and center_y < (target_y + target_h)
           @side = side
           return 1
         end
@@ -832,10 +800,10 @@ module Nekodorif
 
     def check_mikire
       left, top, scrn_w, scrn_h = @window.workarea
-      if @x + @w - @w / 3 > left + scrn_w or \
-        @x + @w / 3 < left or \
-        @y + @h - @h / 3 > top + scrn_h or \
-        @y + @h / 3 < top
+      if (@x + @w - @w / 3) > (left + scrn_w) or \
+        (@x + @w / 3) < left or \
+        (@y + @h - @h / 3) > (top + scrn_h) or \
+        (@y + @h / 3) < top
         return 1
       else
         return 0
@@ -846,7 +814,7 @@ module Nekodorif
       if @settings['state'] == 'fall'
         update_surface()
         update_position()
-        if check_collision() != 0
+        unless check_collision().zero?
           set_state('hit')
           @hit = 1
           if @parent.handle_request('GET', 'get_mode') == 1
@@ -857,9 +825,7 @@ module Nekodorif
             #pass ## FIXME
           end
         end
-        if check_mikire() != 0
-          set_state('dodge')
-        end
+        set_state('dodge') unless check_mikire().zero?
       elsif @settings['state'] == 'hit'
         if @data.include?('hit.waittime')
           wait_time = @data['hit.waittime']
@@ -883,9 +849,7 @@ module Nekodorif
       elsif @settings['state'] == 'after'
         update_surface()
         update_position()
-        if check_mikire() != 0
-          set_state('end')
-        end
+        set_state('end') unless check_mikire().zero?
       elsif @settings['state'] == 'end'
         if @parent.handle_request('GET', 'get_mode') == 1
           @parent.handle_request('NOTIFY', 'send_event', 'Vanish')
