@@ -38,15 +38,16 @@ module NGM
   # 10000以上のIDを持つデータは仮登録
   IDLIMIT = 10000
 
-  ELEMENTS = ['Name', 'SakuraName', 'KeroName', 'GhostType',
-              'HPUrl', 'HPTitle', 'Author', 'PublicUrl', 'ArchiveUrl',
-              'ArchiveSize', 'ArchiveTime', 'Version', 'AIName',
-              'SurfaceSetFlg', 'KisekaeFlg', 'AliasName',
-              'SakuraSurfaceList', 'KeroSurfaceList', 'DeleteFlg',
-              'NetworkUpdateTime', 'AcceptName', 'NetworkUpdateFlg',
-              'SakuraPreviewMD5', 'KeroPreviewMD5', 'ArchiveMD5',
-              'InstallDir', 'ArchiveName', 'UpdateUrl',
-              'AnalysisError', 'InstallCount']
+  ELEMENTS = [
+    'Name', 'SakuraName', 'KeroName', 'GhostType',
+    'HPUrl', 'HPTitle', 'Author', 'PublicUrl', 'ArchiveUrl',
+    'ArchiveSize', 'ArchiveTime', 'Version', 'AIName',
+    'SurfaceSetFlg', 'KisekaeFlg', 'AliasName',
+    'SakuraSurfaceList', 'KeroSurfaceList', 'DeleteFlg',
+    'NetworkUpdateTime', 'AcceptName', 'NetworkUpdateFlg',
+    'SakuraPreviewMD5', 'KeroPreviewMD5', 'ArchiveMD5',
+    'InstallDir', 'ArchiveName', 'UpdateUrl',
+    'AnalysisError', 'InstallCount']
 
   class Catalog_xml
 
@@ -56,31 +57,25 @@ module NGM
       @url = {}
       @cgi = {}
       @datadir = datadir
-      if not Dir.exists?(@datadir)
-        FileUtils.mkdir_p(@datadir)
-      end
+      FileUtils.mkdir_p(@datadir) unless Dir.exists?(@datadir)
       @last_update = '1970-01-01 00:00:00'
       load_MasterList()
     end
 
     # data handling functions
     def get(entry, key)
-      if entry.include?(key)
-        return entry[key]
-      else
-        return nil
-      end
+      entry[key]
     end
 
     def data
-      return @data
+      @data
     end
 
     # updates etc
     def network_update#(updatehook)
       last_update = @last_update
       @last_update = Time.now.strftime('%Y-%m-%d %H:%M:%S')
-      if not @cgi.empty?
+      unless @cgi.empty?
         priority = @cgi.keys.sort
         url = @cgi[priority[-1]][-1]
       else
@@ -88,7 +83,8 @@ module NGM
       end
       begin
         uri = URI.parse(url)
-        uri.query = URI.encode_www_form({time: ['"', last_update, '"'].join(''), charset: 'UTF-8'})
+        uri.query = URI.encode_www_form(
+          {time: "\"#{last_update}\"", charset: 'UTF-8'})
         open(uri) {|f|
           import_from_fileobj(f)
         }
@@ -101,31 +97,30 @@ module NGM
     # private methods
     def load_MasterList
       begin
-        f = open(File.join(@datadir, 'MasterList.xml'), 'r')
-        for _ in import_from_fileobj(f)
-          #pass
-        end
-        f.close()
+        open(File.join(@datadir, 'MasterList.xml'), 'r') {|f|
+          for _ in import_from_fileobj(f)
+            #pass
+          end
+        }
       rescue # IOError
         return
       end
     end
 
     def save_MasterList
-      f = open(File.join(@datadir, 'MasterList.xml'), 'w')
-      export_to_fileobj(f)
-      f.close()
+      open(File.join(@datadir, 'MasterList.xml'), 'w') {|f|
+        export_to_fileobj(f)
+      }
     end
 
     def get_encoding(line)
-      m = Regexp.new('<\?xml version="1.0" encoding="(.+)" \?>').match(line)
-      return m[1]
+      Regexp.new('<\?xml version="1.0" encoding="(.+)" \?>').match(line)[1]
     end
 
     def create_entry(node)
       entry = {}
       for key, text in node
-        raise "assert" unless ELEMENTS.include?(key)
+        fail "assert" unless ELEMENTS.include?(key)
         entry[key] = text
       end
       return entry
@@ -134,8 +129,8 @@ module NGM
     def import_from_fileobj(fileobj)
       line0 = fileobj.readline()
       encoding = get_encoding(line0)
-      if not Encoding.name_list.include?(encoding)
-        raise SystemExit('Unsupported encoding {0}'.format(repr(encoding)))
+      unless Encoding.name_list.include?(encoding)
+        fail SystemExit('Unsupported encoding {0}'.format(repr(encoding)))
       end
       nest = 0
       new_entry = {}
@@ -150,30 +145,28 @@ module NGM
         while Gtk.events_pending?
           Gtk.main_iteration()
         end
-        if line.empty?
-          next
-        end
+        next if line.empty?
         line = line.force_encoding(encoding).encode("UTF-8", :invalid => :replace, :undef => :replace)
         m = re_list.match(line)
-        if m != nil
+        unless m.nil?
           nest += 1
           next
         end
         m = re_setid.match(line)
-        if m != nil
+        unless m.nil?
           nest += 1
           set_id = m[1].to_i
           next
         end
         m = re_set.match(line)
-        if m != nil
+        unless m.nil?
           nest -= 1
           new_entry[set_id] = create_entry(node)
           node = []
           next
         end
         m = re_priority.match(line)
-        if m != nil
+        unless m.nil?
           g = m
           priority = g[1].to_i
           url = g[2]
@@ -185,9 +178,9 @@ module NGM
           next
         end
         m = re_misc.match(line)
-        if m != nil
+        unless m.nil?
           g = m
-          if set_id != nil
+          unless set_id.nil?
             key = g[1]
             text = g[2]
             text = text.sub('&apos;', '\'')                
@@ -203,17 +196,18 @@ module NGM
             #               'SakuraPreviewBaseUrl',
             #               'KeroPreviewBaseUrl',
             #               'ArcMD5BaseUrl', 'NGMUpdateBaseUrl']
-            if key == 'LastUpdate'
+            case key
+            when 'LastUpdate'
               @last_update = text
-            elsif key == 'NGMVersion'
+            when 'NGMVersion'
               version = text.to_f
               if version < 0.51
                 return
               else
                 @version = version
               end
-            elsif ['SakuraPreviewBaseUrl', 'KeroPreviewBaseUrl',
-                   'ArcMD5BaseUrl', 'NGMUpdateBaseUrl'].include?(key)
+            when 'SakuraPreviewBaseUrl', 'KeroPreviewBaseUrl',
+                 'ArcMD5BaseUrl', 'NGMUpdateBaseUrl'
               @url[key] = text
             end
           end
@@ -224,7 +218,7 @@ module NGM
 
     def dump_entry(entry, fileobj)
       for key in ELEMENTS
-        if entry.include?(key) and entry[key] != nil
+        if entry.include?(key) and not entry[key].nil?
           text = entry[key]
           text = text.gsub("&", "&amp;")
           text = text.gsub("<", "&lt;")
@@ -276,7 +270,7 @@ module NGM
     TYPE = ['Sakura', 'Kero']
 
     def image_filename(set_id, side)
-      p = TYPE[side] + "_" + set_id.to_s + ".png"
+      p = (TYPE[side] + "_" + set_id.to_s + ".png")
       d = File.join(@datadir, p)
       if File.exists?(d)
         return d
@@ -288,8 +282,8 @@ module NGM
     def retrieve_image(set_id, side)#, updatehook)
       p = [TYPE[side], '_', set_id, '.png'].join('')
       d = File.join(@datadir, p)
-      if not File.exists?(d)
-        if side == 0
+      unless File.exists?(d)
+        if side.zero?
           url = @url['SakuraPreviewBaseUrl']
         else
           url = @url['KeroPreviewBaseUrl']
@@ -318,7 +312,7 @@ module NGM
         next true # XXX
       end
       @dialog.set_modal(true)
-      @dialog.set_window_position(Gtk::Window::Position::CENTER)
+      @dialog.set_window_position(Gtk::WindowPosition::CENTER)
       label = Gtk::Label.new(label=_('Search for'))
       content_area = @dialog.content_area
       content_area.add(label)
@@ -342,7 +336,7 @@ module NGM
     end
                 
     def get_pattern
-      return @pattern_entry.text
+      @pattern_entry.text
     end
 
     def hide
@@ -350,9 +344,7 @@ module NGM
     end
 
     def show(default: nil)
-      if default != nil
-        set_pattern(default)
-      end
+      set_pattern(default) unless default.nil?
       @dialog.show()
     end
 
@@ -367,11 +359,12 @@ module NGM
     end
 
     def response(widget, response)
-      if response == Gtk::ResponseType::OK
+      case response
+      when Gtk::ResponseType::OK
         ok()
-      elsif response == Gtk::ResponseType::CANCEL
+      when Gtk::ResponseType::CANCEL
         cancel()
-      elsif response == Gtk::ResponseType::DELETE_EVENT
+      when Gtk::ResponseType::DELETE_EVENT
         cancel()
       else
         # should not reach here
@@ -411,47 +404,59 @@ module NGM
           </menubar>
         </ui>"
       @entries = [
-                  [ 'FileMenu', nil, _('_File') ],
-                  [ 'ViewMenu', nil, _('_View') ],
-                  [ 'ArchiveMenu', nil, _('_Archive') ],
-                  [ 'HelpMenu', nil, _('_Help') ],
-                  [ 'Search', nil,                  # name, stock id
-                    _('Search(_F)'), '<control>F',   # label, accelerator
-                    'Search',                        # tooltip
-                    lambda {|a, b| open_search_dialog()} ],
-                  [ 'Search Forward', nil,
-                    _('Search Forward(_S)'), 'F3',
-                    nil,
-                    lambda {|a, b| search_forward()} ],
-                  [ 'Settings', nil,
-                    _('Settings(_O)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'open_preference_dialog')} ],
-                  [ 'DB Network Update', nil,
-                    _('DB Network Update(_N)'), nil,
-                    nil,
-                    lambda {|a, b| network_update()} ],
-                  [ 'Close', nil,
-                    _('Close(_X)'), nil,
-                    nil,
-                    lambda {|a, b| close()} ],
-                  [ 'Mask', nil,
-                    _('Mask(_M)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'open_mask_dialog')} ],
-                  [ 'Reset to Default', nil,
-                    _('Reset to Default(_Y)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'reset_to_default')} ],
-                  [ 'Show All', nil,
-                    _('Show All(_Z)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'show_all')} ],
-                  ]
+        [ 'FileMenu', nil,
+          _('_File'), nil,
+          '',
+          lambda {|a, b| } ],
+        [ 'ViewMenu', nil,
+          _('_View'), nil,
+          '',
+          lambda {|a, b| } ],
+        [ 'ArchiveMenu', nil,
+          _('_Archive'), nil,
+          '',
+          lambda {|a, b| } ],
+        [ 'HelpMenu', nil,
+          _('_Help'), nil,
+          '',
+          lambda {|a, b| } ],
+        [ 'Search', nil,                   # name, stock id
+          _('Search(_F)'), '<control>F',   # label, accelerator
+          'Search',                        # tooltip
+          lambda {|a, b| open_search_dialog()} ],
+        [ 'Search Forward', nil,
+          _('Search Forward(_S)'), 'F3',
+          nil,
+          lambda {|a, b| search_forward()} ],
+        [ 'Settings', nil,
+          _('Settings(_O)'), nil,
+          nil,
+          lambda {|a, b| @parent.handle_request(
+                    'NOTIFY', 'open_preference_dialog')} ],
+        [ 'DB Network Update', nil,
+          _('DB Network Update(_N)'), nil,
+          nil,
+          lambda {|a, b| network_update()} ],
+        [ 'Close', nil,
+          _('Close(_X)'), nil,
+          nil,
+          lambda {|a, b| close()} ],
+        [ 'Mask', nil,
+          _('Mask(_M)'), nil,
+          nil,
+          lambda {|a, b| @parent.handle_request(
+                    'NOTIFY', 'open_mask_dialog')} ],
+        [ 'Reset to Default', nil,
+          _('Reset to Default(_Y)'), nil,
+          nil,
+          lambda {|a, b| @parent.handle_request(
+                    'NOTIFY', 'reset_to_default')} ],
+        [ 'Show All', nil,
+          _('Show All(_Z)'), nil,
+          nil,
+          lambda {|a, b| @parent.handle_request(
+                    'NOTIFY', 'show_all')} ],
+      ]
       @opened = false
       @textview = [nil, nil]
       @darea = [nil, nil]
@@ -483,9 +488,7 @@ module NGM
             event_type, event, *arglist)
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def create_dialog
@@ -495,7 +498,7 @@ module NGM
       @window.signal_connect('delete_event') do |a|
         next close()
       end
-      @window.set_window_position(Gtk::Window::Position::CENTER)
+      @window.set_window_position(Gtk::WindowPosition::CENTER)
       @window.gravity = Gdk::Gravity::CENTER
       actions = Gtk::ActionGroup.new('Actions')
       actions.add_actions(@entries)
@@ -524,7 +527,7 @@ module NGM
       @info_area = create_info_area()
       hbox.pack_start(@info_area, :expand => false, :fill => true, :padding => 10)
       box = Gtk::ButtonBox.new(orientation=Gtk::Orientation::HORIZONTAL)
-      box.set_layout_style(Gtk::ButtonBox::Style::SPREAD)
+      box.set_layout_style(Gtk::ButtonBoxStyle::SPREAD)
       vbox.pack_start(box, :expand => false, :fill => true, :padding => 4)
       box.show()
       button = Gtk::Button.new(:label => _('Previous'))
@@ -560,7 +563,7 @@ module NGM
     end
 
     def search(word)
-      if word != nil and not word.empty?
+      unless word.nil? or word.empty?
         @search_word = word
         if @parent.handle_request('GET', 'search', word)
           update()
@@ -571,7 +574,7 @@ module NGM
     end
 
     def search_forward
-      if not @search_word.empty?
+      unless @search_word.empty?
         if @parent.handle_request('GET', 'search_forward', @search_word)
           update()
         else
@@ -613,7 +616,7 @@ module NGM
     end
 
     def redraw(widget, cr, side)
-      if @surface[side] != nil
+      unless @surface[side].nil?
         cr.set_source(@surface[side], 0, 0)
         cr.set_operator(Cairo::OPERATOR_OVER)
         cr.paint()
@@ -625,7 +628,7 @@ module NGM
 
     def update_surface_area
       for side in [0, 1]
-        if side == 0
+        if side.zero?
           target = 'SakuraName'
         else
           target = 'KeroName'
@@ -636,15 +639,16 @@ module NGM
         filename = @parent.handle_request('GET', 'get_image_filename', side)
         darea = @darea[side]
         darea.realize()
-        if filename != nil and not filename.empty?
+        unless filename.nil? or filename.empty?
           begin
             surface = Pix.create_surface_from_file(filename)
           rescue
             surface = nil
-          end
+          else
             w = surface.width
             h = surface.height
             darea.set_size_request(w, h)
+          end
         else
           surface = nil
         end
@@ -658,7 +662,7 @@ module NGM
       vbox.show()
       hbox = Gtk::Box.new(orientation=Gtk::Orientation::HORIZONTAL)
       box = Gtk::ButtonBox.new(orientation=Gtk::Orientation::HORIZONTAL)
-      box.set_layout_style(Gtk::ButtonBox::Style::SPREAD)
+      box.set_layout_style(Gtk::ButtonBoxStyle::SPREAD)
       box.show()
       button = Gtk::Button.new(:label => _('Install'))
       button.signal_connect(
@@ -773,9 +777,7 @@ module NGM
     end
 
     def show
-      if @opened
-        return
-      end
+      return if @opened
       update()
       @window.show()
       @opened = true
@@ -822,18 +824,14 @@ module NGM
           result = @parent.handle_request(event_type, event, *arglist)
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def get(element)
       if @catalog.data.include?(@current)
         entry = @catalog.data[@current]
         text = @catalog.get(entry, element)
-        if text != nil
-          return text
-        end
+        return text unless text.nil?
       end
       return 'No data'
     end
@@ -849,7 +847,7 @@ module NGM
           for element in ['Name', 'SakuraName', 'KeroName',
                           'Author', 'HPTitle']
             text = @catalog.get(entry, element)
-            if text == nil or text.empty?
+            if text.nil? or text.empty?
               next
             end
             if text.include?(word)
@@ -893,19 +891,19 @@ module NGM
     end
 
     def go_next
-      next_index = @current + 1
+      next_index = (@current + 1)
       if next_index < IDLIMIT and @catalog.data.include?(next_index)
         @current = next_index
       end
     end
 
     def exist_next
-      next_index = @current + 1
+      next_index = (@current + 1)
       return (next_index < IDLIMIT and @catalog.data.include?(next_index))
     end
 
     def previous
-      previous = @current - 1
+      previous = (@current - 1)
       #assert previous < IDLIMIT
       if @catalog.data.include?(previous)
         @current = previous
@@ -913,7 +911,7 @@ module NGM
     end
 
     def exist_previous
-      previous = @current - 1
+      previous = (@current - 1)
       #assert previous < IDLIMIT
       return @catalog.data.include?(previous)
     end
@@ -930,7 +928,7 @@ module NGM
         target_dir = nil
       end
       assert filetype == 'ghost'
-      if target_dir != nil
+      unless target_dir.nil?
         @parent.handle_request('NOTIFY', 'add_sakura', target_dir)
       end
     end
