@@ -40,11 +40,11 @@ module Update
     end
 
     def state
-      return @state
+      @state
     end
 
     def is_active
-      return @state != nil
+      return (not @state.nil?)
     end
 
     def enqueue_event(event,
@@ -54,19 +54,12 @@ module Update
     end
 
     def get_event
-      if @event_queue.empty?
-        return nil
-      else
-        return @event_queue.shift
-      end
+      return nil if @event_queue.empty?
+      return @event_queue.shift
     end
 
     def has_events
-      if @event_queue.empty?
-        return false
-      else
-        return true
-      end
+      return (not @event_queue.empty?)
     end
 
     def start(homeurl, ghostdir, timeout: 60)
@@ -81,7 +74,7 @@ module Update
         @state = nil
         return
       end
-      if not url.scheme == 'http'
+      unless url.scheme == 'http'
         enqueue_event('OnUpdateFailure',
                       :ref0 => 'bad home URL',
                       :ref1 => '',
@@ -95,6 +88,7 @@ module Update
       @path = url.path
       @ghostdir = ghostdir
       @timeout = timeout
+      @redirect_limit = 5
       @state = 0
     end
 
@@ -112,19 +106,13 @@ module Update
       @buffer = []
       if revert
         for path in @backups
-          if File.file?(path)
-            File.rename(path, path[0, path.length - BACKUPSUFFIX.length])
-          end
+          File.rename(path, path[0, path.length - BACKUPSUFFIX.length]) if File.file?(path)
         end
         for path in @newfiles
-          if File.file?(path)
-            File.delete(path)
-          end
+          File.delete(path) if File.file?(path)
         end
         for path in @newdirs
-          if File.directory?(path)
-            FileUtils.remove_entry_secure(path)
-          end
+          FileUtils.remove_entry_secure(path) if File.directory?(path)
         end
         @backups = []
       end
@@ -134,9 +122,7 @@ module Update
 
     def clean_up
       for path in @backups
-        if File.file?(path)
-          File.delete(path)
-        end
+        File.delete(path) if File.file?(path)
       end
       @backups = []
     end
@@ -146,13 +132,13 @@ module Update
     end
 
     def check_timeout
-      return Time.now.to_i - @timestamp > @timeout
+      return (Time.now.to_i - @timestamp) > @timeout
     end
 
     def run
       len_state = 5
       len_pre = 5
-      if @state == nil or \
+      if @state.nil? or \
         @parent.handle_request('GET', 'check_event_queue')
         return false
       elsif @state == 0
@@ -165,10 +151,10 @@ module Update
         get_content()
       elsif @state == 4
         @schedule = make_schedule()
-        if @schedule == nil
+        if @schedule.nil?
           return false
         end
-        @final_state = @schedule.length * len_state + len_pre
+        @final_state = (@schedule.length * len_state + len_pre)
       elsif @state == @final_state
         end_updates()
       elsif (@state - len_pre) % len_state == 0
@@ -199,7 +185,7 @@ module Update
     end
 
     def download(locator, event: false)
-      @locator = URI.escape(locator)
+      @locator = locator # don't use URI.escape here
       @http = Net::HTTP.new(@host, @port)
       if event
         enqueue_event('OnUpdate.OnDownloadBegin',
@@ -233,8 +219,18 @@ module Update
       message = @response.message
       if code == 200
         #pass
-      elsif code == 302 and redirect()
-        return
+      elsif code == 302
+        if redirect()
+          return
+        else
+          enqueue_event('OnUpdateFailure',
+                        :ref0 => 'http redirect error',
+                        :ref1 => '',
+                        :ref2 => '',
+                        :ref3 => 'ghost') # XXX
+          @state = nil
+          return
+        end
       elsif @state == 2 # updates2.dau
         enqueue_event('OnUpdateFailure',
                       :ref0 => code.to_s,
@@ -244,44 +240,39 @@ module Update
         @state = nil
         return
       else
-        filename, checksum = @schedule.pop(0)
+        filename, checksum = @schedule.shift
         Logging::Logging.error(
-          'failed to download ' + filename + ' (' + code.to_s + ' ' + message + ')')
+          "failed to download #{filename} (#{code} #{message})")
         @file_number += 1
         @state += 3
         return
       end
       @buffer = []
-      size = @response.content_length
-      if size == nil
-        @size = nil
-      else
-        @size = size
-      end
+      @size = @response.content_length
       @state += 1
       reset_timeout()
+      @redirect_limit = 5 # reset
     end
 
     def redirect
-      location = @response.getheader('location', nil)
-      if location == nil
-        return false
-      end
+      @redirect_limit -= 1
+      return false if @redirect_limit < 0
+      location = @response['location']
+      return false if location.nil?
       begin
         url = URI.parse(location)
       rescue
         return false
       end
-      if url.scheme != 'http'
-        return false
-      end
-      Logging::Logging.info('redirected to ' + location)
-      @http.close()
+      return false if url.scheme != 'http'
+      return false if url.path.empty?
+      Logging::Logging.info("redirected to #{location}")
+      @http.finish if @http.started?
       @host = url.host
       @port = url.port
-      @path = url.path.dirname
+      @path = url.path
       @state -= 2
-      download(url[2])
+      download(@path)
       return true
     end
 
@@ -297,7 +288,7 @@ module Update
           @state = nil
           stop(:revert => true)
           return
-        elsif data == nil
+        elsif data.nil?
           return
         end
       elsif @response.code != '200'
@@ -310,10 +301,8 @@ module Update
         stop(:revert => true)
         return
       end
-      if not data.empty?
-        @buffer = data
-      end
-      if @size == nil or data.length < @size
+      @buffer = data unless data.empty?
+      if @size.nil? or data.length < @size
         enqueue_event('OnUpdateFailure',
                       :ref0 => 'timeout',
                       :ref1 => '',
@@ -339,8 +328,8 @@ module Update
 
     def make_schedule
       schedule = parse_updates2_dau()
-      if schedule != nil
-        @num_files = schedule.length - 1
+      unless schedule.nil?
+        @num_files = (schedule.length - 1)
         @file_number = 0
         list = []
         for x, y in schedule
@@ -360,7 +349,7 @@ module Update
     end
 
     def get_schedule
-      return @schedule
+      @schedule
     end
 
     def parse_updates2_dau
@@ -377,10 +366,10 @@ module Update
           @state = nil
           return nil
         end
-        if filename == ""
-          next
+        next if filename == ""
+        unless checksum.nil?
+          checksum = checksum.encode('ascii', :invalid => :replace, :undef => :replace) # XXX
         end
-        checksum = checksum.encode('ascii', :invalid => :replace, :undef => :replace) # XXX
         path = File.join(@ghostdir, adjust_path(filename))
         begin
           f = open(path, 'rb')
@@ -389,10 +378,8 @@ module Update
         rescue # IOError # does not exist or broken
           data = nil
         end
-        if data != nil
-          if checksum == Digest::MD5.hexdigest(data)
-            next
-          end
+        unless data.nil?
+          next if checksum == Digest::MD5.hexdigest(data)
         end
         schedule << [filename, checksum]
       end
@@ -411,7 +398,7 @@ module Update
       if digest == checksum
         path = File.join(@ghostdir, adjust_path(filename))
         subdir = File.dirname(path)
-        if not Dir.exists?(subdir)
+        unless Dir.exists?(subdir)
           subroot = subdir
           while true
             head, tail = File.split(subroot)
@@ -491,7 +478,7 @@ module Update
 
     def end_updates
       filelist = parse_delete_txt()
-      if not filelist.empty?
+      unless filelist.empty?
         for filename in filelist
           path = File.join(@ghostdir, filename)
           if File.exists?(path) and File.file?(path)
@@ -532,9 +519,7 @@ module Update
         f = open(File.join(@ghostdir, 'delete.txt'), 'rb')
         for line in f
           line = line.strip()
-          if line.empty?
-            next
-          end
+          next if line.empty?
           filename = line
           filelist << Home.get_normalized_path(filename)
         end
